plot.autoGAM_frame: plot.autoGAM_frame

Description Usage Arguments Value Author(s) See Also Examples

View source: R/plot.autoGAM_frame.R

Description

Plot method for an object of class autoGAM_frame.

Usage

1
2
## S3 method for class 'autoGAM_frame'
plot(x, type = "final", ...)

Arguments

x

An object of class autoGAM_frame.

type

The type of the plot to be created. Valid inputs are 'forms' that returns the whole plots of evaluated continuous predictors & 'final' (default value) that returns the plots related to the best forms obtained from the evaluation process.

...

Other plot arguments (Not being used for objects of class 'autoGAM_frame').

Value

Desired plots that were requested by the type argument.

Author(s)

Shahin Roshani

See Also

https://shahin-roshani.github.io/autoGAM/articles/autoGAM.html

Examples

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
## Not run: 

my_mtcars <- mtcars %>% mutate_at('vs',as.factor)

carsGAM <- autoGAM_frame(mpg~disp+drat+vs,data=my_mtcars) %>% backward_select %>% autoGAM_fit

plot(carsGAM,type='forms')

plot(carsGAM)


## End(Not run)

Shahin-Roshani/autoGAM documentation built on Dec. 18, 2021, 1:05 p.m.